# This variable indicates that the module was installed
# with setup.py. This is used to detect older versions of
# pyrazer that were not installed with setup.py into the system.
PYRAZER_SETUP_PY = True

from pyrazer.main import *
